==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/LocalTypeSet.h <==
// class soot.jimple.toolkits.pointer.LocalTypeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad8bccc435d17437 java_util_BitSet
// @dep_class 9512a288467b6ad6 soot_jimple_toolkits_pointer_LocalTypeSet

// header file dependencies
// @dep_header java_util_BitSet

#include "java/util/BitSet.h"

#ifndef _JC_soot_jimple_toolkits_pointer_LocalTypeSet_H_
#define _JC_soot_jimple_toolkits_pointer_LocalTypeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Local$object;
struct _jc_soot_RefType$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_refs	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$refs	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$nonrefs	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vmethods	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtable	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$_init$ed851f4c3b3c73fb(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$clearAllBits$a8ae8646eabfba0c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *);
extern jint _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$indexOf$3e2ee0a5c2bacbb0(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_soot_RefType$object *);
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$killLocal$df7743705455a471(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$localCopy$9184ebe5b84ce0dc(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$localMustBeSubtypeOf$21962c30117933a8(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_soot_RefType$object *);
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$setAllBits$d33fc51b547bc166(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$clearAllBits$a8ae8646eabfba0c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$indexOf$3e2ee0a5c2bacbb0;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$killLocal$df7743705455a471;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$localCopy$9184ebe5b84ce0dc;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$localMustBeSubtypeOf$21962c30117933a8;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$setAllBits$d33fc51b547bc166;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vmethods {
	void	(*clearAllBits$a8ae8646eabfba0c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *);
	jint	(*indexOf$3e2ee0a5c2bacbb0)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_soot_RefType$object *);
	void	(*killLocal$df7743705455a471)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *);
	void	(*localCopy$9184ebe5b84ce0dc)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_object *);
	void	(*localMustBeSubtypeOf$21962c30117933a8)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_soot_RefType$object *);
	void	(*setAllBits$d33fc51b547bc166)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_BitSet$vmethods	java_util_BitSet;
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vmethods	soot_jimple_toolkits_pointer_LocalTypeSet;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_refs {
	struct _jc_object	*locals;
	struct _jc_object	*types;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$refs {
    _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_refs	soot_jimple_toolkits_pointer_LocalTypeSet;
    _jc_java_util_BitSet$sub_refs	java_util_BitSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_BitSet$sub_nonrefs	java_util_BitSet;
    _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_nonrefs	soot_jimple_toolkits_pointer_LocalTypeSet;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object {
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype _jc_soot_jimple_toolkits_pointer_LocalTypeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_LocalTypeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_LocalTypeSet$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_LocalTypeSet_H_ */

==> jc-1.4.5.tar.gz: soot/jimple/toolkits/pointer/LocalTypeSet.h <==
// class soot.jimple.toolkits.pointer.LocalTypeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad8bccc435d17437 java_util_BitSet
// @dep_class 9512a288467b6ad6 soot_jimple_toolkits_pointer_LocalTypeSet

// header file dependencies
// @dep_header java_util_BitSet

#include "java/util/BitSet.h"

#ifndef _JC_soot_jimple_toolkits_pointer_LocalTypeSet_H_
#define _JC_soot_jimple_toolkits_pointer_LocalTypeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Local$object;
struct _jc_soot_RefType$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_refs	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$refs	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$nonrefs	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vmethods	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtable	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$_init$ed851f4c3b3c73fb(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$clearAllBits$a8ae8646eabfba0c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$indexOf$3e2ee0a5c2bacbb0(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$killLocal$df7743705455a471(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$localCopy$9184ebe5b84ce0dc(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$localMustBeSubtypeOf$21962c30117933a8(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method$setAllBits$d33fc51b547bc166(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$clearAllBits$a8ae8646eabfba0c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$indexOf$3e2ee0a5c2bacbb0;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$killLocal$df7743705455a471;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$localCopy$9184ebe5b84ce0dc;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$localMustBeSubtypeOf$21962c30117933a8;
extern _jc_method _jc_soot_jimple_toolkits_pointer_LocalTypeSet$method_info$setAllBits$d33fc51b547bc166;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vmethods {
	void	(*clearAllBits$a8ae8646eabfba0c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *) _JC_JCNI_ATTR;
	jint	(*indexOf$3e2ee0a5c2bacbb0)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
	void	(*killLocal$df7743705455a471)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*localCopy$9184ebe5b84ce0dc)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*localMustBeSubtypeOf$21962c30117933a8)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *, struct _jc_object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
	void	(*setAllBits$d33fc51b547bc166)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_BitSet$vmethods	java_util_BitSet;
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vmethods	soot_jimple_toolkits_pointer_LocalTypeSet;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_refs {
	struct _jc_object	*locals;
	struct _jc_object	*types;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$refs {
    _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_refs	soot_jimple_toolkits_pointer_LocalTypeSet;
    _jc_java_util_BitSet$sub_refs	java_util_BitSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_BitSet$sub_nonrefs	java_util_BitSet;
    _jc_soot_jimple_toolkits_pointer_LocalTypeSet$sub_nonrefs	soot_jimple_toolkits_pointer_LocalTypeSet;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object {
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_LocalTypeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_LocalTypeSet$vtype _jc_soot_jimple_toolkits_pointer_LocalTypeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_LocalTypeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_LocalTypeSet$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_LocalTypeSet_H_ */
